@@ -1,8 +1,9 @@
 from dataclasses import dataclass
-from typing import Optional, List
-from annotell.input_api.model.abstract.abstract_models import Response
 from datetime import datetime
 from enum import Enum
+from typing import List, Optional
+
+from annotell.input_api.model.abstract.abstract_models import Response
 from annotell.input_api.util import ts_to_dt
 
 
@@ -25,6 +26,7 @@ class Input(Response):
     input_type: str
     status: InputStatus
     created: datetime
+    annotation_types: List[str]
     calibration_id: Optional[str]
     view_link: Optional[str]
     error_message: Optional[str]
@@ -38,6 +40,7 @@ class Input(Response):
             input_type=js["inputType"],
             status=js["status"],
             created=ts_to_dt(js["created"]),
+            annotation_types=js["annotationTypes"],
             view_link=js.get("viewLink"),
             calibration_id=js.get("calibrationId"),
             error_message=js.get("errorMessage")
