@@ -47,7 +47,7 @@ class CreateableInputAPIResource:
 
         body = self._append_annotation_types(body, annotation_types)
 
-        feature_flags = feature_flags if feature_flags is not None else FeatureFlags.defaults
+        feature_flags = feature_flags if feature_flags is not None else FeatureFlags.defaults()
 
         body = self._append_feature_flags(body, feature_flags)
 
