@@ -3,6 +3,7 @@ from typing import Optional, List
 
 import annotell.input_api.model.input as input_model
 import annotell.input_api.model.input.lidars_sequence as ls_model
+from annotell.input_api.model.input.feature_flags import FeatureFlags
 from annotell.input_api.resources.abstract import CreateableInputAPIResource
 
 log = logging.getLogger(__name__)
@@ -17,7 +18,8 @@ class LidarsSequence(CreateableInputAPIResource):
         project: Optional[str] = None,
         batch: Optional[str] = None,
         annotation_types: Optional[List[str]] = None,
-        dryrun: bool = False
+        dryrun: bool = False,
+        feature_flags: Optional[FeatureFlags] = None
     ) -> Optional[input_model.CreateInputResponse]:
         """
         Upload files and create an input of type ``LidarsSequence``.
@@ -27,6 +29,7 @@ class LidarsSequence(CreateableInputAPIResource):
         :param batch: batch, defaults to latest open batch
         :param annotation_types: annotation types for which to produce annotations for. Defaults to `None` (corresponds to all available annotation types). Passing an empty list will result in the same behaviour as passing `None`.
         :param dryrun: If True the files/metadata will be validated but no input job will be created.
+        :param feature_flags Optional set of feature flags to control the input creation process.
         :returns CreateInputResponse: Class containing id of the created input job, or `None` if dryrun.
         """
 
@@ -34,7 +37,8 @@ class LidarsSequence(CreateableInputAPIResource):
         payload = lidars_sequence.to_dict()
 
         response = self._post_input_request(
-            self.path, payload, project=project, batch=batch, annotation_types=annotation_types, imu_data=imu_data, dryrun=dryrun
+            self.path, payload, project=project, batch=batch, annotation_types=annotation_types, imu_data=imu_data,
+            dryrun=dryrun, feature_flags=feature_flags
         )
 
         if dryrun:
